## 0.0.15

This new version includes an update to the environment to fix bokeh versions and a version bump.

### New Features

- None in this release

### Bug Fixes

- Fixed bokeh versions in the environment to ensure compatibility and smooth operation (8c48f7) (Eric Ma)

### Deprecations

- None in this release
